@@ -6,10 +6,6 @@ typedef struct _Efl_Ui_Tab_Pager_Data                   Efl_Ui_Tab_Pager_Data;
 struct _Efl_Ui_Tab_Pager_Data
 {
    Eo                                      *tab_bar;
-
-   int                                      cnt;
-   int                                      cur;
-   Eina_List                               *tab_pages;
 };
 
 
