@@ -13,7 +13,11 @@ typedef Eo Efl_Ui_Text;
 
 
 #endif
-/** Efl UI text class
+#ifdef EFL_BETA_API_SUPPORT
+/** A flexible text widget which can be static (as a label) or editable by the
+ * user (as a text entry). It provides all sorts of editing facilities like
+ * automatic scrollbars, virtual keyboard, clipboard, configurable context
+ * menus, password mode or autocapitalization, for example.
  *
  * @ingroup Efl_Ui_Text
  */
@@ -22,33 +26,34 @@ typedef Eo Efl_Ui_Text;
 EWAPI const Efl_Class *efl_ui_text_class_get(void);
 
 /**
- * @brief Enable or disable scrolling in entry
+ * @brief Enable or disable scrolling in the widget.
  *
- * Normally the entry is not scrollable unless you enable it with this call.
+ * When scrolling is enabled scrollbars will appear if the text does not fit
+ * the widget size.
  *
  * @param[in] obj The object.
- * @param[in] scroll @c true if it is to be scrollable, @c false otherwise.
+ * @param[in] scroll @c true to enable scrolling. Default is @c false.
  *
  * @ingroup Efl_Ui_Text
  */
 EOAPI void efl_ui_text_scrollable_set(Eo *obj, Eina_Bool scroll);
 
 /**
- * @brief Get the scrollable state of the entry
+ * @brief Enable or disable scrolling in the widget.
  *
- * Normally the entry is not scrollable. This gets the scrollable state of the
- * entry.
+ * When scrolling is enabled scrollbars will appear if the text does not fit
+ * the widget size.
  *
  * @param[in] obj The object.
  *
- * @return @c true if it is to be scrollable, @c false otherwise.
+ * @return @c true to enable scrolling. Default is @c false.
  *
  * @ingroup Efl_Ui_Text
  */
 EOAPI Eina_Bool efl_ui_text_scrollable_get(const Eo *obj);
 
 /**
- * @brief Set the attribute to show the input panel in case of only a user's
+ * @brief The attribute to show the input panel in case of only a user's
  * explicit Mouse Up event. It doesn't request to show the input panel even
  * though it has focus.
  *
@@ -56,23 +61,20 @@ EOAPI Eina_Bool efl_ui_text_scrollable_get(const Eo *obj);
  * @param[in] ondemand If @c true, the input panel will be shown in case of
  * only Mouse up event. (Focus event will be ignored.)
  *
- * @since 1.9
- *
  * @ingroup Efl_Ui_Text
  */
 EOAPI void efl_ui_text_input_panel_show_on_demand_set(Eo *obj, Eina_Bool ondemand);
 
 /**
- * @brief Get the attribute to show the input panel in case of only an user's
- * explicit Mouse Up event.
+ * @brief The attribute to show the input panel in case of only a user's
+ * explicit Mouse Up event. It doesn't request to show the input panel even
+ * though it has focus.
  *
  * @param[in] obj The object.
  *
  * @return If @c true, the input panel will be shown in case of only Mouse up
  * event. (Focus event will be ignored.)
  *
- * @since 1.9
- *
  * @ingroup Efl_Ui_Text
  */
 EOAPI Eina_Bool efl_ui_text_input_panel_show_on_demand_get(const Eo *obj);
@@ -88,8 +90,7 @@ EOAPI Eina_Bool efl_ui_text_input_panel_show_on_demand_get(const Eo *obj);
 EOAPI void efl_ui_text_context_menu_disabled_set(Eo *obj, Eina_Bool disabled);
 
 /**
- * @brief This returns whether the entry's contextual (longpress) menu is
- * disabled.
+ * @brief This disables the entry's contextual (longpress) menu.
  *
  * @param[in] obj The object.
  *
@@ -102,10 +103,7 @@ EOAPI Eina_Bool efl_ui_text_context_menu_disabled_get(const Eo *obj);
 /**
  * @brief Control pasting of text and images for the widget.
  *
- * Normally the entry allows both text and images to be pasted. By setting
- * cnp_mode to be #ELM_CNP_MODE_NO_IMAGE this prevents images from being copied
- * or pasted. By setting cnp_mode to be #ELM_CNP_MODE_PLAINTEXT this remove all
- * tags in text .
+ * Normally the entry allows both text and images to be pasted.
  *
  * @note This only changes the behaviour of text.
  *
@@ -114,13 +112,14 @@ EOAPI Eina_Bool efl_ui_text_context_menu_disabled_get(const Eo *obj);
  *
  * @ingroup Efl_Ui_Text
  */
-EOAPI void efl_ui_text_cnp_mode_set(Eo *obj, Efl_Selection_Format format);
+EOAPI void efl_ui_text_cnp_mode_set(Eo *obj, Efl_Ui_Selection_Format format);
 
 /**
- * @brief Getting elm_entry text paste/drop mode.
+ * @brief Control pasting of text and images for the widget.
  *
- * Normally the entry allows both text and images to be pasted. This gets the
- * copy & paste mode of the entry.
+ * Normally the entry allows both text and images to be pasted.
+ *
+ * @note This only changes the behaviour of text.
  *
  * @param[in] obj The object.
  *
@@ -128,10 +127,10 @@ EOAPI void efl_ui_text_cnp_mode_set(Eo *obj, Efl_Selection_Format format);
  *
  * @ingroup Efl_Ui_Text
  */
-EOAPI Efl_Selection_Format efl_ui_text_cnp_mode_get(const Eo *obj);
+EOAPI Efl_Ui_Selection_Format efl_ui_text_cnp_mode_get(const Eo *obj);
 
 /**
- * @brief Set the language mode of the input panel.
+ * @brief The language mode of the input panel.
  *
  * This API can be used if you want to show the alphabet keyboard mode.
  *
@@ -143,7 +142,9 @@ EOAPI Efl_Selection_Format efl_ui_text_cnp_mode_get(const Eo *obj);
 EOAPI void efl_ui_text_input_panel_language_set(Eo *obj, Elm_Input_Panel_Lang lang);
 
 /**
- * @brief Get the language mode of the input panel.
+ * @brief The language mode of the input panel.
+ *
+ * This API can be used if you want to show the alphabet keyboard mode.
  *
  * @param[in] obj The object.
  *
@@ -164,7 +165,7 @@ EOAPI Elm_Input_Panel_Lang efl_ui_text_input_panel_language_get(const Eo *obj);
 EOAPI void efl_ui_text_selection_handler_disabled_set(Eo *obj, Eina_Bool disabled);
 
 /**
- * @brief This returns whether the entry's selection handlers are disabled.
+ * @brief This disables the entry's selection handlers.
  *
  * @param[in] obj The object.
  *
@@ -180,21 +181,17 @@ EOAPI Eina_Bool efl_ui_text_selection_handler_disabled_get(const Eo *obj);
  * @param[in] obj The object.
  * @param[in] variation Layout variation type.
  *
- * @since 1.8
- *
  * @ingroup Efl_Ui_Text
  */
 EOAPI void efl_ui_text_input_panel_layout_variation_set(Eo *obj, int variation);
 
 /**
- * @brief Get the input panel layout variation of the entry
+ * @brief Set the input panel layout variation of the entry
  *
  * @param[in] obj The object.
  *
  * @return Layout variation type.
  *
- * @since 1.8
- *
  * @ingroup Efl_Ui_Text
  */
 EOAPI int efl_ui_text_input_panel_layout_variation_get(const Eo *obj);
@@ -210,7 +207,7 @@ EOAPI int efl_ui_text_input_panel_layout_variation_get(const Eo *obj);
 EOAPI void efl_ui_text_autocapital_type_set(Eo *obj, Elm_Autocapital_Type autocapital_type);
 
 /**
- * @brief Get the autocapitalization type on the immodule.
+ * @brief Set the autocapitalization type on the immodule.
  *
  * @param[in] obj The object.
  *
@@ -234,7 +231,10 @@ EOAPI Elm_Autocapital_Type efl_ui_text_autocapital_type_get(const Eo *obj);
 EOAPI void efl_ui_text_password_mode_set(Eo *obj, Eina_Bool password);
 
 /**
- * @brief Get whether the entry is set to password mode.
+ * @brief Sets the entry to password mode.
+ *
+ * In password mode entries are implicitly single line and the display of any
+ * text inside them is replaced with asterisks (*).
  *
  * @param[in] obj The object.
  *
@@ -256,8 +256,7 @@ EOAPI Eina_Bool efl_ui_text_password_mode_get(const Eo *obj);
 EOAPI void efl_ui_text_input_panel_return_key_disabled_set(Eo *obj, Eina_Bool disabled);
 
 /**
- * @brief Get whether the return key on the input panel should be disabled or
- * not.
+ * @brief Set the return key on the input panel to be disabled.
  *
  * @param[in] obj The object.
  *
@@ -268,7 +267,7 @@ EOAPI void efl_ui_text_input_panel_return_key_disabled_set(Eo *obj, Eina_Bool di
 EOAPI Eina_Bool efl_ui_text_input_panel_return_key_disabled_get(const Eo *obj);
 
 /**
- * @brief Set whether the entry should allow predictive text.
+ * @brief Whether the entry should allow predictive text.
  *
  * @param[in] obj The object.
  * @param[in] prediction Whether the entry should allow predictive text.
@@ -278,7 +277,7 @@ EOAPI Eina_Bool efl_ui_text_input_panel_return_key_disabled_get(const Eo *obj);
 EOAPI void efl_ui_text_prediction_allow_set(Eo *obj, Eina_Bool prediction);
 
 /**
- * @brief Get whether the entry allows predictive text.
+ * @brief Whether the entry should allow predictive text.
  *
  * @param[in] obj The object.
  *
@@ -300,7 +299,8 @@ EOAPI Eina_Bool efl_ui_text_prediction_allow_get(const Eo *obj);
 EOAPI void efl_ui_text_input_hint_set(Eo *obj, Elm_Input_Hints hints);
 
 /**
- * @brief Gets the value of input hint.
+ * @brief Sets the input hint which allows input methods to fine-tune their
+ * behavior.
  *
  * @param[in] obj The object.
  *
@@ -321,7 +321,7 @@ EOAPI Elm_Input_Hints efl_ui_text_input_hint_get(const Eo *obj);
 EOAPI void efl_ui_text_input_panel_layout_set(Eo *obj, Elm_Input_Panel_Layout layout);
 
 /**
- * @brief Get the input panel layout of the entry.
+ * @brief Set the input panel layout of the entry.
  *
  * @param[in] obj The object.
  *
@@ -345,7 +345,10 @@ EOAPI Elm_Input_Panel_Layout efl_ui_text_input_panel_layout_get(const Eo *obj);
 EOAPI void efl_ui_text_input_panel_return_key_type_set(Eo *obj, Elm_Input_Panel_Return_Key_Type return_key_type);
 
 /**
- * @brief Get the "return" key type.
+ * @brief Set the "return" key type. This type is used to set string or icon on
+ * the "return" key of the input panel.
+ *
+ * An input panel displays the string or icon associated with this type.
  *
  * @param[in] obj The object.
  *
@@ -367,7 +370,7 @@ EOAPI Elm_Input_Panel_Return_Key_Type efl_ui_text_input_panel_return_key_type_ge
 EOAPI void efl_ui_text_input_panel_enabled_set(Eo *obj, Eina_Bool enabled);
 
 /**
- * @brief Get the attribute to show the input panel automatically.
+ * @brief Sets the attribute to show the input panel automatically.
  *
  * @param[in] obj The object.
  *
@@ -379,16 +382,16 @@ EOAPI void efl_ui_text_input_panel_enabled_set(Eo *obj, Eina_Bool enabled);
 EOAPI Eina_Bool efl_ui_text_input_panel_enabled_get(const Eo *obj);
 
 /**
- * @brief Set whether the return key on the input panel is disabled
- * automatically when entry has no text.
+ * @brief Whether the return key on the input panel is disabled automatically
+ * when entry has no text.
  *
  * If @c enabled is @c true, the return key on input panel is disabled when the
  * entry has no text. The return key on the input panel is automatically
- * enabled when the entry has text. The default value is @c false.
+ * enabled when the entry has text.
  *
  * @param[in] obj The object.
- * @param[in] enabled If @c enabled is @c true, the return key is automatically
- * disabled when the entry has no text.
+ * @param[in] enabled If @c true, the return key is automatically disabled when
+ * the entry has no text.
  *
  * @ingroup Efl_Ui_Text
  */
@@ -538,14 +541,6 @@ EOAPI void efl_ui_text_context_menu_item_add(Eo *obj, const char *label, const c
  */
 EOAPI Efl_Text_Cursor_Cursor *efl_ui_text_cursor_new(Eo *obj);
 
-EWAPI extern const Efl_Event_Description _EFL_UI_TEXT_EVENT_ACTIVATED;
-
-/** Called when entry is activated
- *
- * @ingroup Efl_Ui_Text
- */
-#define EFL_UI_TEXT_EVENT_ACTIVATED (&(_EFL_UI_TEXT_EVENT_ACTIVATED))
-
 EWAPI extern const Efl_Event_Description _EFL_UI_TEXT_EVENT_CHANGED;
 
 /** Called when entry changes
@@ -672,5 +667,6 @@ EWAPI extern const Efl_Event_Description _EFL_UI_TEXT_EVENT_CURSOR_CHANGED_MANUA
  * @ingroup Efl_Ui_Text
  */
 #define EFL_UI_TEXT_EVENT_CURSOR_CHANGED_MANUAL (&(_EFL_UI_TEXT_EVENT_CURSOR_CHANGED_MANUAL))
+#endif /* EFL_BETA_API_SUPPORT */
 
 #endif
