@@ -50,7 +50,7 @@ EWAPI const Efl_Class *efl_canvas_proxy_class_get(void);
  *
  * @ingroup Efl_Canvas_Proxy
  */
-EOAPI Eina_Bool efl_canvas_proxy_source_set(Eo *obj, Efl_Canvas_Object *src) EINA_ARG_NONNULL(2);
+EOAPI Eina_Bool efl_canvas_proxy_source_set(Eo *obj, Efl_Canvas_Object *src);
 
 /**
  * @brief The source object for this proxy.
