@@ -13,6 +13,7 @@ typedef Eo Efl_Canvas_Text_Factory;
 
 
 #endif
+#ifdef EFL_BETA_API_SUPPORT
 /**
  * @brief Object factory that creates Efl.Canvas.Object objects.
  *
@@ -22,8 +23,6 @@ typedef Eo Efl_Canvas_Text_Factory;
  * or a key associated with a real-path in a hashtable or something else
  * entirely.
  *
- * @since 1.21
- *
  * @ingroup Efl_Canvas_Text_Factory
  */
 #define EFL_CANVAS_TEXT_FACTORY_INTERFACE efl_canvas_text_factory_interface_get()
@@ -38,10 +37,9 @@ EWAPI const Efl_Class *efl_canvas_text_factory_interface_get(void);
  * @param[in] object The parent of the created object
  * @param[in] key Key that is associated to an item object
  *
- * @since 1.21
- *
  * @ingroup Efl_Canvas_Text_Factory
  */
-EOAPI Efl_Canvas_Object *efl_canvas_text_factory_create(Eo *obj, Efl_Canvas_Object *object, const char *key);
+EOAPI Efl_Canvas_Object *efl_canvas_text_factory_create(Eo *obj, Efl_Canvas_Object *object, const char *key) EFL_TRANSFER_OWNERSHIP;
+#endif /* EFL_BETA_API_SUPPORT */
 
 #endif
