@@ -4,12 +4,15 @@
 #ifndef _EVAS_CANVAS3D_TYPES_EOT_TYPES
 #define _EVAS_CANVAS3D_TYPES_EOT_TYPES
 
+#ifdef EFL_BETA_API_SUPPORT
 /** A type for floating value
  *
  * @ingroup Evas
  */
 typedef double Evas_Real;
+#endif /* EFL_BETA_API_SUPPORT */
 
+#ifdef EFL_BETA_API_SUPPORT
 /** Type of 3D Object
  *
  * @since 1.10
@@ -31,7 +34,9 @@ typedef enum
                                        *
                                        * @since 1.15 */
 } Evas_Canvas3D_Object_Type;
+#endif /* EFL_BETA_API_SUPPORT */
 
+#ifdef EFL_BETA_API_SUPPORT
 /** State of the Evas 3D
  *
  * @since 1.10
@@ -127,7 +132,9 @@ typedef enum
                                 *
                                 * @since 1.18 */
 } Evas_Canvas3D_State;
+#endif /* EFL_BETA_API_SUPPORT */
 
+#ifdef EFL_BETA_API_SUPPORT
 /** Transform space
  *
  * @since 1.10
@@ -140,7 +147,9 @@ typedef enum
   EVAS_CANVAS3D_SPACE_PARENT, /**< Parent coordinate space */
   EVAS_CANVAS3D_SPACE_WORLD /**< World coordinate space */
 } Evas_Canvas3D_Space;
+#endif /* EFL_BETA_API_SUPPORT */
 
+#ifdef EFL_BETA_API_SUPPORT
 /** Types of a node
  *
  * @since 1.10
@@ -149,12 +158,17 @@ typedef enum
  */
 typedef enum
 {
+  EVAS_CANVAS3D_NODE_TYPE_UNKNOWN = -1 /* +1 */, /**< Unknown node type
+                                                  *
+                                                  * @since 1.21 */
   EVAS_CANVAS3D_NODE_TYPE_NODE = 0, /**< Node with no items */
   EVAS_CANVAS3D_NODE_TYPE_CAMERA, /**< Node which can contain camera object */
   EVAS_CANVAS3D_NODE_TYPE_LIGHT, /**< Node which can contain light object */
   EVAS_CANVAS3D_NODE_TYPE_MESH /**< Node which can contain mesh objects */
 } Evas_Canvas3D_Node_Type;
+#endif /* EFL_BETA_API_SUPPORT */
 
+#ifdef EFL_BETA_API_SUPPORT
 /** Types of node orientation
  *
  * @since 1.13
@@ -182,7 +196,9 @@ typedef enum
   EVAS_CANVAS3D_NODE_ORIENTATION_TYPE_QUATERNION /**< Node orientation is given
                                                   * as a quaternion */
 } Evas_Canvas3D_Node_Orientation_Type;
+#endif /* EFL_BETA_API_SUPPORT */
 
+#ifdef EFL_BETA_API_SUPPORT
 /** Index formats
  *
  * @since 1.10
@@ -197,7 +213,9 @@ typedef enum
   EVAS_CANVAS3D_INDEX_FORMAT_UNSIGNED_SHORT /**< Index is of type unsigned short
                                              */
 } Evas_Canvas3D_Index_Format;
+#endif /* EFL_BETA_API_SUPPORT */
 
+#ifdef EFL_BETA_API_SUPPORT
 /** Frustum modes
  *
  * @since 1.12
@@ -210,7 +228,9 @@ typedef enum
   EVAS_CANVAS3D_FRUSTUM_MODE_AABB, /**< Axis-aligned bounding box */
   EVAS_CANVAS3D_FRUSTUM_MODE_CENTRAL_POINT /**< Central point */
 } Evas_Canvas3D_Frustum_Mode;
+#endif /* EFL_BETA_API_SUPPORT */
 
+#ifdef EFL_BETA_API_SUPPORT
 /** Vertex assembly modes. Vertex assembly represents how the vertices are
  * organized into geometric primitives.
  *
@@ -235,7 +255,9 @@ typedef enum
   EVAS_CANVAS3D_VERTEX_ASSEMBLY_TRIANGLE_FAN /**< Vertices are organized as a
                                               * triangle fan */
 } Evas_Canvas3D_Vertex_Assembly;
+#endif /* EFL_BETA_API_SUPPORT */
 
+#ifdef EFL_BETA_API_SUPPORT
 /** Comparsion functions for testing(alpha, depth, stencil) in fragment shader
  *
  * @since 1.14
@@ -259,7 +281,9 @@ typedef enum
                                     * than or equal to the reference value */
   EVAS_CANVAS3D_COMPARISON_ALWAYS /**< Always passes (initial value) */
 } Evas_Canvas3D_Comparison;
+#endif /* EFL_BETA_API_SUPPORT */
 
+#ifdef EFL_BETA_API_SUPPORT
 /** Wrap modes for texture units
  *
  * @since 1.14
@@ -274,7 +298,9 @@ typedef enum
   EVAS_CANVAS3D_WRAP_MODE_REFLECT /**< Values will be repeated in a reflected
                                    * manner */
 } Evas_Canvas3D_Wrap_Mode;
+#endif /* EFL_BETA_API_SUPPORT */
 
+#ifdef EFL_BETA_API_SUPPORT
 /** Filters for texture units
  *
  * @since 1.14
@@ -296,7 +322,9 @@ typedef enum
                                                      * mipmap and interpolate
                                                      */
 } Evas_Canvas3D_Texture_Filter;
+#endif /* EFL_BETA_API_SUPPORT */
 
+#ifdef EFL_BETA_API_SUPPORT
 /** Mesh primitive
  *
  * @since 1.12
@@ -324,7 +352,9 @@ typedef enum
   EVAS_CANVAS3D_MESH_PRIMITIVE_COUNT /**< Sentinel value to indicate last enum
                                       * field during iteration */
 } Evas_Canvas3D_Mesh_Primitive;
+#endif /* EFL_BETA_API_SUPPORT */
 
+#ifdef EFL_BETA_API_SUPPORT
 /** Mode of mesh primitive
  *
  * @since 1.15
@@ -340,7 +370,9 @@ typedef enum
   EVAS_CANVAS3D_PRIMITIVE_MODE_ALTERNATIVE_UV /**< Ptimitive with alternative uv
                                                * (supported for sphere) */
 } Evas_Canvas3D_Primitive_Mode;
+#endif /* EFL_BETA_API_SUPPORT */
 
+#ifdef EFL_BETA_API_SUPPORT
 /** Shader shade modes
  *
  * @since 1.10
@@ -364,7 +396,9 @@ typedef enum
   EVAS_CANVAS3D_SHADER_MODE_POST_PROCESSING_FXAA /**< Render full screen quard
                                                   */
 } Evas_Canvas3D_Shader_Mode;
+#endif /* EFL_BETA_API_SUPPORT */
 
+#ifdef EFL_BETA_API_SUPPORT
 /** Vertex attribute IDs
  *
  * @since 1.10
@@ -380,7 +414,9 @@ typedef enum
   EVAS_CANVAS3D_VERTEX_ATTRIB_COLOR, /**< vertex color */
   EVAS_CANVAS3D_VERTEX_ATTRIB_TEXCOORD /**< vertex texture coordinate */
 } Evas_Canvas3D_Vertex_Attrib;
+#endif /* EFL_BETA_API_SUPPORT */
 
+#ifdef EFL_BETA_API_SUPPORT
 /** Blending function
  *
  * @since 1.14
@@ -438,7 +474,9 @@ typedef enum
                                                * where i = min(as, ka, ad)/ka
                                                */
 } Evas_Canvas3D_Blend_Func;
+#endif /* EFL_BETA_API_SUPPORT */
 
+#ifdef EFL_BETA_API_SUPPORT
 /** Material attributes
  *
  * @since 1.10
@@ -453,6 +491,7 @@ typedef enum
   EVAS_CANVAS3D_MATERIAL_ATTRIB_EMISSION, /**< emission term */
   EVAS_CANVAS3D_MATERIAL_ATTRIB_NORMAL /**< Normal map term */
 } Evas_Canvas3D_Material_Attrib;
+#endif /* EFL_BETA_API_SUPPORT */
 
 
 #endif
